CA04-Cl01
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Portal links |
clickAndWait | link=Añadir portal link |
type | id_name_es | Portal link ca04-cl01
type | id_slug | portal-link-ca04-cl01
type | id_external_url | http://www.yaco.es
select | id_category | label=Primary link
clickAndWait | _continue |
open | / |
verifyTextPresent | Portal link ca04-cl01 |
clickAndWait | //li[@id='portal-link-portal-link-ca04-cl01']/a/span |
verifyText | link=Términos Generales | Términos Generales
goBackAndWait |  |
open | /admin/ |
clickAndWait | link=Portal links |
clickAndWait | link=Portal link ca04-cl01 |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |